#!/bin/sh
# 2010-10-27, barton@maccc.de
#
# This script downloads and installs the Mac OS X "NagCollect" script
# and registers it with launchd(8).
# NagCollect is a suite of scripts that do periodic service checks
# and submits the results as "passive checks" to Nagios.
#

NAME="NagCollect-R2.1"
URL="http://up2down.net/file/get/id/4577cb95268d41f5548b26924746a277e2cb9123/dl/1284978036"
CONF="/usr/local/etc/nagcollect.conf"
SERVER="http://arthur.barton.de/"

install() {
	echo "Downloading $NAME.dmg ..."
	curl -# -o "/tmp/$NAME.dmg" "$URL"

	echo "Mounting disk image ..."
	hdiutil attach -quiet -nobrowse "/tmp/$NAME.dmg"

	echo "Installing ..."
	sudo -p "Password of %u: " \
	 installer -pkg "/Volumes/$NAME/$NAME.mpkg" -target /

	echo "Unmounting disk image ..."
	diskutil eject "/Volumes/$NAME"
}

configure() {
	if [ `id -u` -ne 0 ]; then
		echo "Can't validate configuration: you are not root!"
		return
	fi
	if [ ! -r "$CONF" ]; then
		echo "Can't validate configuration: not found!? ($CONF)"
		return
	fi
	echo "Validating configuration ..."
	. "$CONF"
	if [ -z "$SERVER_URL" ]; then
		echo "No SERVER_URL, updating it ..."
		sed -e "s|SERVER_URL=\"\"|SERVER_URL=\"$SERVER\"|g" -i '' "$CONF"
	fi
	if [ -z "$CLIENT_KEY" ]; then
		echo "No CLIENT_KEY, updating it ..."
		read -e -p "Enter \"client key\": "
		sed -e "s|CLIENT_KEY=\"\"|CLIENT_KEY=\"$REPLY\"|g" -i '' "$CONF"
	fi
	if [ -z "$CLIENT_ID" ]; then
		echo "No CLIENT_ID, updating it ..."
		read -e -p "Enter \"client ID\": "
		sed -e "s|CLIENT_ID=\"\"|CLIENT_ID=\"$REPLY\"|g" -i '' "$CONF"
	fi
}

enable() {
	echo "Enabling LaunchDaemon script ..."
	sudo -p "Password of %u: " \
	 launchctl load -w /Library/LaunchDaemons/de.barton.nagcollect
}

case "$1" in
    "--config")
	configure
	;;
    "")
	install
	sudo  -p "Password of %u: " sh "$0" --config
	enable
	;;
    *)
	echo "Usage: $0"
	exit 1	
esac
